@@ -3,7 +3,7 @@ package Set::Similarity;
 use strict;
 use warnings;
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 use Carp 'croak';
 
@@ -32,7 +32,7 @@ sub _any {
 	return [grep { $any->{$_} } keys %$any];
   }
   elsif (ref($any)) {
-   return [];
+    return [];
   }
   else {
     return [$self->ngrams($any,$width)];
@@ -46,13 +46,8 @@ sub ngrams {
   $word ||= '';
 
   my @ngrams;
-  #return @ngrams unless ($width <= length($word));
-  
-  if ($width > length($word)) {
-    for (1..$width-length($word)) {
-      $word .= ' ';
-    }
-  }
+
+  return ($word) unless ($width <= length($word));
 
   for my $i (0..length($word)-$width) {
     my $ngram = substr $word,$i,$width;
